@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "auto-compile" "2.1.3"
+(define-package "auto-compile" "20251111.1802"
   "Automatically compile Emacs Lisp libraries."
   '((emacs "27.1"))
   :url "https://github.com/emacscollective/auto-compile"
-  :commit "cc51aea86617cab6cb1ef76672a343f2bf3206c1"
-  :revdesc "v2.1.3-0-gcc51aea86617"
+  :commit "7d314cc13515a1bd6ded29e69a9d4be4aff205c3"
+  :revdesc "7d314cc13515"
   :keywords '("compile" "convenience" "lisp")
   :authors '(("Jonas Bernoulli" . "emacs.auto-compile@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.auto-compile@jonas.bernoulli.dev")))
